from firstimpression.constants import APIS
from firstimpressionbeta.api.request import request_json

##################################################################################################
# CONSTANTS
##################################################################################################

# NAME = APIS['solaredge']
URL = 'https://monitoringpublic.solaredge.com/solaredge-web/p/kiosk/kioskData?locale=nl_NL'
GUID = 'df83c872-7416-4817-8578-80240d3e03dc'


##################################################################################################
# MAIN FUNCTIONS API
##################################################################################################

def run_api(guid):
    response = request_json(URL, params={'guid':guid}, method='post')
    print(response)


##################################################################################################
# MEDIA FUNCTIONS
##################################################################################################


##################################################################################################
# GET FUNCTIONS
##################################################################################################


##################################################################################################
# PARSE FUNCTIONS
##################################################################################################

run_api(GUID)